Index: uspace/lib/ui/include/ui/scrollbar.h
===================================================================
--- uspace/lib/ui/include/ui/scrollbar.h	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/include/ui/scrollbar.h	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -1,4 +1,4 @@
 /*
- * Copyright (c) 2022 Jiri Svoboda
+ * Copyright (c) 2023 Jiri Svoboda
  * All rights reserved.
  *
@@ -54,5 +54,5 @@
 extern void ui_scrollbar_set_rect(ui_scrollbar_t *, gfx_rect_t *);
 extern errno_t ui_scrollbar_paint(ui_scrollbar_t *);
-extern gfx_coord_t ui_scrollbar_through_length(ui_scrollbar_t *);
+extern gfx_coord_t ui_scrollbar_trough_length(ui_scrollbar_t *);
 extern gfx_coord_t ui_scrollbar_move_length(ui_scrollbar_t *);
 extern gfx_coord_t ui_scrollbar_get_pos(ui_scrollbar_t *);
@@ -60,9 +60,9 @@
 extern void ui_scrollbar_set_pos(ui_scrollbar_t *, gfx_coord_t);
 extern void ui_scrollbar_thumb_press(ui_scrollbar_t *, gfx_coord2_t *);
-extern void ui_scrollbar_up_through_press(ui_scrollbar_t *);
-extern void ui_scrollbar_down_through_press(ui_scrollbar_t *);
+extern void ui_scrollbar_upper_trough_press(ui_scrollbar_t *);
+extern void ui_scrollbar_lower_trough_press(ui_scrollbar_t *);
 extern void ui_scrollbar_release(ui_scrollbar_t *, gfx_coord2_t *);
 extern void ui_scrollbar_update(ui_scrollbar_t *, gfx_coord2_t *);
-extern void ui_scrollbar_throughs_update(ui_scrollbar_t *, gfx_coord2_t *);
+extern void ui_scrollbar_troughs_update(ui_scrollbar_t *, gfx_coord2_t *);
 extern void ui_scrollbar_up(ui_scrollbar_t *);
 extern void ui_scrollbar_down(ui_scrollbar_t *);
Index: uspace/lib/ui/src/clickmatic.c
===================================================================
--- uspace/lib/ui/src/clickmatic.c	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/src/clickmatic.c	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -1,4 +1,4 @@
 /*
- * Copyright (c) 2022 Jiri Svoboda
+ * Copyright (c) 2023 Jiri Svoboda
  * All rights reserved.
  *
@@ -35,5 +35,5 @@
  * Clickmatic is used to periodically generate events in particular cases
  * when a mouse button is held down, such as when holding the button or
- * through of a scrollbar.
+ * trough of a scrollbar.
  */
 
Index: uspace/lib/ui/src/resource.c
===================================================================
--- uspace/lib/ui/src/resource.c	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/src/resource.c	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -86,6 +86,6 @@
 	gfx_color_t *entry_sel_text_fg_color = NULL;
 	gfx_color_t *entry_sel_text_bg_color = NULL;
-	gfx_color_t *sbar_through_color = NULL;
-	gfx_color_t *sbar_act_through_color = NULL;
+	gfx_color_t *sbar_trough_color = NULL;
+	gfx_color_t *sbar_act_trough_color = NULL;
 	errno_t rc;
 
@@ -221,10 +221,10 @@
 
 	rc = gfx_color_new_rgb_i16(0xe4e4, 0xe4e4, 0xe4e4,
-	    &sbar_through_color);
+	    &sbar_trough_color);
 	if (rc != EOK)
 		goto error;
 
 	rc = gfx_color_new_rgb_i16(0x5858, 0x5858, 0x5858,
-	    &sbar_act_through_color);
+	    &sbar_act_trough_color);
 	if (rc != EOK)
 		goto error;
@@ -265,6 +265,6 @@
 	resource->entry_sel_text_bg_color = entry_sel_text_bg_color;
 
-	resource->sbar_through_color = sbar_through_color;
-	resource->sbar_act_through_color = sbar_act_through_color;
+	resource->sbar_trough_color = sbar_trough_color;
+	resource->sbar_act_trough_color = sbar_act_trough_color;
 
 	*rresource = resource;
@@ -327,8 +327,8 @@
 		gfx_color_delete(entry_act_bg_color);
 
-	if (sbar_through_color != NULL)
-		gfx_color_delete(sbar_through_color);
-	if (sbar_act_through_color != NULL)
-		gfx_color_delete(sbar_act_through_color);
+	if (sbar_trough_color != NULL)
+		gfx_color_delete(sbar_trough_color);
+	if (sbar_act_trough_color != NULL)
+		gfx_color_delete(sbar_act_trough_color);
 
 	if (tface != NULL)
@@ -376,6 +376,6 @@
 	gfx_color_t *entry_sel_text_bg_color = NULL;
 	gfx_color_t *entry_act_bg_color = NULL;
-	gfx_color_t *sbar_through_color = NULL;
-	gfx_color_t *sbar_act_through_color = NULL;
+	gfx_color_t *sbar_trough_color = NULL;
+	gfx_color_t *sbar_act_trough_color = NULL;
 	errno_t rc;
 
@@ -497,9 +497,9 @@
 		goto error;
 
-	rc = gfx_color_new_ega(0x07, &sbar_through_color);
-	if (rc != EOK)
-		goto error;
-
-	rc = gfx_color_new_ega(0x07, &sbar_act_through_color);
+	rc = gfx_color_new_ega(0x07, &sbar_trough_color);
+	if (rc != EOK)
+		goto error;
+
+	rc = gfx_color_new_ega(0x07, &sbar_act_trough_color);
 	if (rc != EOK)
 		goto error;
@@ -540,6 +540,6 @@
 	resource->entry_sel_text_bg_color = entry_sel_text_bg_color;
 
-	resource->sbar_through_color = sbar_through_color;
-	resource->sbar_act_through_color = sbar_act_through_color;
+	resource->sbar_trough_color = sbar_trough_color;
+	resource->sbar_act_trough_color = sbar_act_trough_color;
 
 	*rresource = resource;
@@ -601,8 +601,8 @@
 	if (entry_sel_text_bg_color != NULL)
 		gfx_color_delete(entry_sel_text_bg_color);
-	if (sbar_through_color != NULL)
-		gfx_color_delete(sbar_through_color);
-	if (sbar_act_through_color != NULL)
-		gfx_color_delete(sbar_act_through_color);
+	if (sbar_trough_color != NULL)
+		gfx_color_delete(sbar_trough_color);
+	if (sbar_act_trough_color != NULL)
+		gfx_color_delete(sbar_act_trough_color);
 
 	if (tface != NULL)
@@ -665,6 +665,6 @@
 	gfx_color_delete(resource->entry_sel_text_bg_color);
 
-	gfx_color_delete(resource->sbar_through_color);
-	gfx_color_delete(resource->sbar_act_through_color);
+	gfx_color_delete(resource->sbar_trough_color);
+	gfx_color_delete(resource->sbar_act_trough_color);
 
 	gfx_font_close(resource->font);
Index: uspace/lib/ui/src/scrollbar.c
===================================================================
--- uspace/lib/ui/src/scrollbar.c	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/src/scrollbar.c	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -1,4 +1,4 @@
 /*
- * Copyright (c) 2022 Jiri Svoboda
+ * Copyright (c) 2023 Jiri Svoboda
  * All rights reserved.
  *
@@ -35,13 +35,13 @@
  * Anatomy of a horizontal scrollbar:
  *
- *       Up                Down
- *      through           through
- * +---+------+--------+---------+---+
- * | < |      |   |||  |         | > |
- * +---+------+--------+---------+---+
- *  Up           Thumb           Down
- * button                       button
- *
- *     +-------- Through --------+
+ *        Upper             Lower
+ *       trough            trough
+ *  +---+------+--------+---------+---+
+ *  | < |      |   |||  |         | > |
+ *  +---+------+--------+---------+---+
+ *   Up           Thumb           Down
+ * button                        button
+ *
+ *     +-------- Trough --------+
  *
  * Scrollbar uses the same terminology whether it is running in horizontal
@@ -51,8 +51,8 @@
  * The thumb can be dragged to a specific position, resulting in a move
  * event. The up/down buttons generate up/down events. Pressing a mouse
- * button on the up/down through generates page up / page down events.
- *
- * Pressing and holding down mouse button on up / down button or up / down
- * through will auto-scroll (using clickmatic).
+ * button on the upper/lower trough generates page up / page down events.
+ *
+ * Pressing and holding down mouse button on up / down button or upper /
+ * lower trough will auto-scroll (using clickmatic).
  */
 
@@ -360,5 +360,5 @@
 }
 
-/** Determine scrollbar through length.
+/** Determine scrollbar trough length.
  *
  * Return the size of the space within which the thumb can move
@@ -366,7 +366,7 @@
  *
  * @param scrollbar Scrollbar
- * @return Scrollbar through length in pixels
- */
-gfx_coord_t ui_scrollbar_through_length(ui_scrollbar_t *scrollbar)
+ * @return Scrollbar trough length in pixels
+ */
+gfx_coord_t ui_scrollbar_trough_length(ui_scrollbar_t *scrollbar)
 {
 	ui_resource_t *resource;
@@ -396,5 +396,5 @@
 gfx_coord_t ui_scrollbar_move_length(ui_scrollbar_t *scrollbar)
 {
-	return ui_scrollbar_through_length(scrollbar) -
+	return ui_scrollbar_trough_length(scrollbar) -
 	    scrollbar->thumb_len;
 }
@@ -417,5 +417,5 @@
 	    ui_scrollbar_min_thumb_len;
 
-	max_len = ui_scrollbar_through_length(scrollbar);
+	max_len = ui_scrollbar_trough_length(scrollbar);
 	if (len < min_len)
 		len = min_len;
@@ -459,5 +459,5 @@
 		scrollbar->pos = pos;
 		(void) ui_scrollbar_paint(scrollbar);
-		ui_scrollbar_throughs_update(scrollbar,
+		ui_scrollbar_troughs_update(scrollbar,
 		    &scrollbar->last_curs_pos);
 	}
@@ -487,26 +487,26 @@
 		goto error;
 
-	/* Paint scrollbar up through */
+	/* Paint scrollbar upper trough */
 	rc = gfx_set_color(resource->gc,
-	    scrollbar->up_through_held && scrollbar->up_through_inside ?
-	    resource->sbar_act_through_color :
-	    resource->sbar_through_color);
-	if (rc != EOK)
-		goto error;
-
-	rc = gfx_fill_rect(resource->gc, &geom.up_through_rect);
-	if (rc != EOK)
-		goto error;
-
-	/* Paint scrollbar down through */
+	    scrollbar->upper_trough_held && scrollbar->upper_trough_inside ?
+	    resource->sbar_act_trough_color :
+	    resource->sbar_trough_color);
+	if (rc != EOK)
+		goto error;
+
+	rc = gfx_fill_rect(resource->gc, &geom.upper_trough_rect);
+	if (rc != EOK)
+		goto error;
+
+	/* Paint scrollbar lower trough */
 
 	rc = gfx_set_color(resource->gc,
-	    scrollbar->down_through_held && scrollbar->down_through_inside ?
-	    resource->sbar_act_through_color :
-	    resource->sbar_through_color);
-	if (rc != EOK)
-		goto error;
-
-	rc = gfx_fill_rect(resource->gc, &geom.down_through_rect);
+	    scrollbar->lower_trough_held && scrollbar->lower_trough_inside ?
+	    resource->sbar_act_trough_color :
+	    resource->sbar_trough_color);
+	if (rc != EOK)
+		goto error;
+
+	rc = gfx_fill_rect(resource->gc, &geom.lower_trough_rect);
 	if (rc != EOK)
 		goto error;
@@ -561,8 +561,8 @@
 	ui_scrollbar_get_geom(scrollbar, &geom);
 
-	/* Paint scrollbar through */
-
-	rc = ui_paint_text_rect(resource, &geom.through_rect,
-	    resource->sbar_through_color, "\u2592");
+	/* Paint scrollbar trough */
+
+	rc = ui_paint_text_rect(resource, &geom.trough_rect,
+	    resource->sbar_trough_color, "\u2592");
 	if (rc != EOK)
 		goto error;
@@ -571,5 +571,5 @@
 
 	rc = ui_paint_text_rect(resource, &geom.thumb_rect,
-	    resource->sbar_through_color, "\u25a0");
+	    resource->sbar_trough_color, "\u25a0");
 	if (rc != EOK)
 		goto error;
@@ -647,9 +647,9 @@
 		geom->up_btn_rect.p1.y = orect.p1.y;
 
-		/* Through */
-		geom->through_rect.p0.x = geom->up_btn_rect.p1.x;
-		geom->through_rect.p0.y = irect.p0.y;
-		geom->through_rect.p1.x = orect.p1.x - btn_len;
-		geom->through_rect.p1.y = irect.p1.y;
+		/* Trough */
+		geom->trough_rect.p0.x = geom->up_btn_rect.p1.x;
+		geom->trough_rect.p0.y = irect.p0.y;
+		geom->trough_rect.p1.x = orect.p1.x - btn_len;
+		geom->trough_rect.p1.y = irect.p1.y;
 
 		/* Thumb */
@@ -661,16 +661,16 @@
 		geom->thumb_rect.p1.y = orect.p1.y;
 
-		/* Up through */
-		geom->up_through_rect.p0 = geom->through_rect.p0;
-		geom->up_through_rect.p1.x = geom->thumb_rect.p0.x;
-		geom->up_through_rect.p1.y = geom->through_rect.p1.y;
-
-		/* Down through */
-		geom->down_through_rect.p0.x = geom->thumb_rect.p1.x;
-		geom->down_through_rect.p0.y = geom->through_rect.p0.y;
-		geom->down_through_rect.p1 = geom->through_rect.p1;
+		/* Upper trough */
+		geom->upper_trough_rect.p0 = geom->trough_rect.p0;
+		geom->upper_trough_rect.p1.x = geom->thumb_rect.p0.x;
+		geom->upper_trough_rect.p1.y = geom->trough_rect.p1.y;
+
+		/* Lower trough */
+		geom->lower_trough_rect.p0.x = geom->thumb_rect.p1.x;
+		geom->lower_trough_rect.p0.y = geom->trough_rect.p0.y;
+		geom->lower_trough_rect.p1 = geom->trough_rect.p1;
 
 		/* Down button */
-		geom->down_btn_rect.p0.x = geom->through_rect.p1.x;
+		geom->down_btn_rect.p0.x = geom->trough_rect.p1.x;
 		geom->down_btn_rect.p0.y = orect.p0.y;
 		geom->down_btn_rect.p1.x = orect.p1.x;
@@ -683,9 +683,9 @@
 		geom->up_btn_rect.p1.y = orect.p0.y + btn_len;
 
-		/* Through */
-		geom->through_rect.p0.x = irect.p0.x;
-		geom->through_rect.p0.y = geom->up_btn_rect.p1.y;
-		geom->through_rect.p1.x = irect.p1.x;
-		geom->through_rect.p1.y = orect.p1.y - btn_len;
+		/* Trough */
+		geom->trough_rect.p0.x = irect.p0.x;
+		geom->trough_rect.p0.y = geom->up_btn_rect.p1.y;
+		geom->trough_rect.p1.x = irect.p1.x;
+		geom->trough_rect.p1.y = orect.p1.y - btn_len;
 
 		/* Thumb */
@@ -697,17 +697,17 @@
 		    scrollbar->thumb_len;
 
-		/* Up through */
-		geom->up_through_rect.p0 = geom->through_rect.p0;
-		geom->up_through_rect.p1.x = geom->through_rect.p1.x;
-		geom->up_through_rect.p1.y = geom->thumb_rect.p0.y;
-
-		/* Down through */
-		geom->down_through_rect.p0.x = geom->through_rect.p0.x;
-		geom->down_through_rect.p0.y = geom->thumb_rect.p1.y;
-		geom->down_through_rect.p1 = geom->through_rect.p1;
+		/* Upper trough */
+		geom->upper_trough_rect.p0 = geom->trough_rect.p0;
+		geom->upper_trough_rect.p1.x = geom->trough_rect.p1.x;
+		geom->upper_trough_rect.p1.y = geom->thumb_rect.p0.y;
+
+		/* Lower trough */
+		geom->lower_trough_rect.p0.x = geom->trough_rect.p0.x;
+		geom->lower_trough_rect.p0.y = geom->thumb_rect.p1.y;
+		geom->lower_trough_rect.p1 = geom->trough_rect.p1;
 
 		/* Down button */
 		geom->down_btn_rect.p0.x = orect.p0.x;
-		geom->down_btn_rect.p0.y = geom->through_rect.p1.y;
+		geom->down_btn_rect.p0.y = geom->trough_rect.p1.y;
 		geom->down_btn_rect.p1.x = orect.p1.x;
 		geom->down_btn_rect.p1.y = orect.p1.y;
@@ -732,14 +732,14 @@
 }
 
-/** Press down scrollbar up through.
- *
- * @param scrollbar Scrollbar
- */
-void ui_scrollbar_up_through_press(ui_scrollbar_t *scrollbar)
+/** Press down scrollbar upper trough.
+ *
+ * @param scrollbar Scrollbar
+ */
+void ui_scrollbar_upper_trough_press(ui_scrollbar_t *scrollbar)
 {
 	ui_clickmatic_t *clickmatic = ui_get_clickmatic(scrollbar->ui);
 
-	scrollbar->up_through_held = true;
-	scrollbar->up_through_inside = true;
+	scrollbar->upper_trough_held = true;
+	scrollbar->upper_trough_inside = true;
 
 	ui_clickmatic_set_cb(clickmatic, &ui_scrollbar_clickmatic_page_up_cb,
@@ -748,14 +748,14 @@
 }
 
-/** Press down scrollbar down through.
- *
- * @param scrollbar Scrollbar
- */
-void ui_scrollbar_down_through_press(ui_scrollbar_t *scrollbar)
+/** Press down scrollbar lower trough.
+ *
+ * @param scrollbar Scrollbar
+ */
+void ui_scrollbar_lower_trough_press(ui_scrollbar_t *scrollbar)
 {
 	ui_clickmatic_t *clickmatic = ui_get_clickmatic(scrollbar->ui);
 
-	scrollbar->down_through_held = true;
-	scrollbar->down_through_inside = true;
+	scrollbar->lower_trough_held = true;
+	scrollbar->lower_trough_inside = true;
 
 	ui_clickmatic_set_cb(clickmatic, &ui_scrollbar_clickmatic_page_down_cb,
@@ -778,11 +778,11 @@
 	}
 
-	if (scrollbar->up_through_held || scrollbar->down_through_held) {
+	if (scrollbar->upper_trough_held || scrollbar->lower_trough_held) {
 		clickmatic = ui_get_clickmatic(scrollbar->ui);
 		ui_clickmatic_release(clickmatic);
 		ui_clickmatic_set_cb(clickmatic, NULL, NULL);
 
-		scrollbar->up_through_held = false;
-		scrollbar->down_through_held = false;
+		scrollbar->upper_trough_held = false;
+		scrollbar->lower_trough_held = false;
 		(void) ui_scrollbar_paint(scrollbar);
 	}
@@ -791,10 +791,10 @@
 /** Update state of scrollbar throuhgs.
  *
- * Update state of scrollbar throughs after mouse cursor or thumb has moved.
+ * Update state of scrollbar troughs after mouse cursor or thumb has moved.
  *
  * @param scrollbar Scrollbar
  * @param pos Mouse cursor position
  */
-void ui_scrollbar_throughs_update(ui_scrollbar_t *scrollbar, gfx_coord2_t *pos)
+void ui_scrollbar_troughs_update(ui_scrollbar_t *scrollbar, gfx_coord2_t *pos)
 {
 	ui_scrollbar_geom_t geom;
@@ -804,20 +804,20 @@
 	ui_scrollbar_get_geom(scrollbar, &geom);
 
-	inside_up = gfx_pix_inside_rect(pos, &geom.up_through_rect);
-	inside_down = gfx_pix_inside_rect(pos, &geom.down_through_rect);
-
-	if (inside_up && !scrollbar->up_through_inside) {
-		scrollbar->up_through_inside = true;
+	inside_up = gfx_pix_inside_rect(pos, &geom.upper_trough_rect);
+	inside_down = gfx_pix_inside_rect(pos, &geom.lower_trough_rect);
+
+	if (inside_up && !scrollbar->upper_trough_inside) {
+		scrollbar->upper_trough_inside = true;
 		(void) ui_scrollbar_paint(scrollbar);
-	} else if (!inside_up && scrollbar->up_through_inside) {
-		scrollbar->up_through_inside = false;
+	} else if (!inside_up && scrollbar->upper_trough_inside) {
+		scrollbar->upper_trough_inside = false;
 		(void) ui_scrollbar_paint(scrollbar);
 	}
 
-	if (inside_down && !scrollbar->down_through_inside) {
-		scrollbar->down_through_inside = true;
+	if (inside_down && !scrollbar->lower_trough_inside) {
+		scrollbar->lower_trough_inside = true;
 		(void) ui_scrollbar_paint(scrollbar);
-	} else if (!inside_down && scrollbar->down_through_inside) {
-		scrollbar->down_through_inside = false;
+	} else if (!inside_down && scrollbar->lower_trough_inside) {
+		scrollbar->lower_trough_inside = false;
 		(void) ui_scrollbar_paint(scrollbar);
 	}
@@ -843,5 +843,5 @@
 	}
 
-	ui_scrollbar_throughs_update(scrollbar, pos);
+	ui_scrollbar_troughs_update(scrollbar, pos);
 }
 
@@ -866,5 +866,5 @@
 }
 
-/** Scrollbar up through was pressed.
+/** Scrollbar upper trough was pressed.
  *
  * @param scrollbar Scrollbar
@@ -876,5 +876,5 @@
 }
 
-/** Scrollbar down through was pressed.
+/** Scrollbar lower trough was pressed.
  *
  * @param scrollbar Scrollbar
@@ -927,16 +927,16 @@
 			return ui_claimed;
 		}
-		if (gfx_pix_inside_rect(&pos, &geom.up_through_rect)) {
-			ui_scrollbar_up_through_press(scrollbar);
+		if (gfx_pix_inside_rect(&pos, &geom.upper_trough_rect)) {
+			ui_scrollbar_upper_trough_press(scrollbar);
 			return ui_claimed;
 		}
-		if (gfx_pix_inside_rect(&pos, &geom.down_through_rect)) {
-			ui_scrollbar_down_through_press(scrollbar);
+		if (gfx_pix_inside_rect(&pos, &geom.lower_trough_rect)) {
+			ui_scrollbar_lower_trough_press(scrollbar);
 			return ui_claimed;
 		}
 		break;
 	case POS_RELEASE:
-		if (scrollbar->thumb_held || scrollbar->up_through_held ||
-		    scrollbar->down_through_held) {
+		if (scrollbar->thumb_held || scrollbar->upper_trough_held ||
+		    scrollbar->lower_trough_held) {
 			ui_scrollbar_release(scrollbar, &pos);
 			return ui_claimed;
@@ -1118,5 +1118,5 @@
 }
 
-/** Scrollbar clickmatic up through click event.
+/** Scrollbar clickmatic upper trough click event.
  *
  * @param clickmatic Clickmatic
@@ -1127,9 +1127,9 @@
 	ui_scrollbar_t *scrollbar = (ui_scrollbar_t *)arg;
 
-	if (scrollbar->up_through_inside)
+	if (scrollbar->upper_trough_inside)
 		ui_scrollbar_page_up(scrollbar);
 }
 
-/** Scrollbar clickmatic down through click event.
+/** Scrollbar clickmatic lower trough click event.
  *
  * @param clickmatic Clickmatic
@@ -1140,5 +1140,5 @@
 	ui_scrollbar_t *scrollbar = (ui_scrollbar_t *)arg;
 
-	if (scrollbar->down_through_inside)
+	if (scrollbar->lower_trough_inside)
 		ui_scrollbar_page_down(scrollbar);
 }
Index: uspace/lib/ui/private/resource.h
===================================================================
--- uspace/lib/ui/private/resource.h	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/private/resource.h	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -118,8 +118,8 @@
 	gfx_color_t *entry_sel_text_bg_color;
 
-	/** Scrollbar through color */
-	gfx_color_t *sbar_through_color;
-	/** Scrollbar active through color */
-	gfx_color_t *sbar_act_through_color;
+	/** Scrollbar trough color */
+	gfx_color_t *sbar_trough_color;
+	/** Scrollbar active trough color */
+	gfx_color_t *sbar_act_trough_color;
 
 	/** Expose callback or @c NULL */
Index: uspace/lib/ui/private/scrollbar.h
===================================================================
--- uspace/lib/ui/private/scrollbar.h	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/private/scrollbar.h	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -1,4 +1,4 @@
 /*
- * Copyright (c) 2022 Jiri Svoboda
+ * Copyright (c) 2023 Jiri Svoboda
  * All rights reserved.
  *
@@ -69,12 +69,12 @@
 	/** Thumb is currently held down */
 	bool thumb_held;
-	/** Up through is currently held down */
-	bool up_through_held;
-	/** Pointer is inside up through */
-	bool up_through_inside;
-	/** Down through is currently held down */
-	bool down_through_held;
-	/** Pointer is inside down through */
-	bool down_through_inside;
+	/** Upper trough is currently held down */
+	bool upper_trough_held;
+	/** Pointer is inside upper trough */
+	bool upper_trough_inside;
+	/** Lower trough is currently held down */
+	bool lower_trough_held;
+	/** Pointer is inside lower trough */
+	bool lower_trough_inside;
 	/** Position where thumb was pressed */
 	gfx_coord2_t press_pos;
@@ -83,5 +83,5 @@
 	/** Thumb position */
 	gfx_coord_t pos;
 	/** Last cursor position (when through is held) */
 	gfx_coord2_t last_curs_pos;
 };
@@ -94,12 +94,12 @@
 	/** Up button rectangle */
 	gfx_rect_t up_btn_rect;
-	/** Through rectangle */
-	gfx_rect_t through_rect;
-	/** Up through rectangle */
-	gfx_rect_t up_through_rect;
+	/** Trough rectangle */
+	gfx_rect_t trough_rect;
+	/** Upper trough rectangle */
+	gfx_rect_t upper_trough_rect;
 	/** Thumb rectangle */
 	gfx_rect_t thumb_rect;
-	/** Down through rectangle */
-	gfx_rect_t down_through_rect;
+	/** Lower trough rectangle */
+	gfx_rect_t lower_trough_rect;
 	/** Down button rectangle */
 	gfx_rect_t down_btn_rect;
@@ -83,5 +83,5 @@
 	/** Thumb position */
 	gfx_coord_t pos;
-	/** Last cursor position (when through is held) */
+	/** Last cursor position (when trough is held) */
 	gfx_coord2_t last_curs_pos;
 };
Index: uspace/lib/ui/test/scrollbar.c
===================================================================
--- uspace/lib/ui/test/scrollbar.c	(revision 5e758e4edd4c6f54a07739ae94e5b26a912ab7a3)
+++ uspace/lib/ui/test/scrollbar.c	(revision 8f049928445f06042a36af4db46b4151cc5b20aa)
@@ -1,4 +1,4 @@
 /*
- * Copyright (c) 2022 Jiri Svoboda
+ * Copyright (c) 2023 Jiri Svoboda
  * All rights reserved.
  *
@@ -284,6 +284,6 @@
 }
 
-/** ui_scrollbar_through_length() gives correct scrollbar through length */
-PCUT_TEST(through_length)
+/** ui_scrollbar_trough_length() gives correct scrollbar trough length */
+PCUT_TEST(trough_length)
 {
 	ui_t *ui = NULL;
@@ -316,5 +316,5 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	length = ui_scrollbar_through_length(scrollbar);
+	length = ui_scrollbar_trough_length(scrollbar);
 
 	/* Total length minus buttons */
@@ -620,6 +620,6 @@
 }
 
-/** Press and release up through */
-PCUT_TEST(up_through_press_release)
+/** Press and release upper trough */
+PCUT_TEST(upper_trough_press_release)
 {
 	ui_t *ui = NULL;
@@ -654,8 +654,8 @@
 	ui_scrollbar_set_cb(scrollbar, &test_scrollbar_cb, &resp);
 
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
-
-	ui_scrollbar_up_through_press(scrollbar);
-	PCUT_ASSERT_TRUE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
+
+	ui_scrollbar_upper_trough_press(scrollbar);
+	PCUT_ASSERT_TRUE(scrollbar->upper_trough_held);
 	PCUT_ASSERT_TRUE(resp.page_up);
 
@@ -665,13 +665,13 @@
 
 	ui_scrollbar_release(scrollbar, &pos);
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
-
-	ui_scrollbar_destroy(scrollbar);
-	ui_window_destroy(window);
-	ui_destroy(ui);
-}
-
-/** Press and release down through */
-PCUT_TEST(down_through_press_release)
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
+
+	ui_scrollbar_destroy(scrollbar);
+	ui_window_destroy(window);
+	ui_destroy(ui);
+}
+
+/** Press and release lower trough */
+PCUT_TEST(lower_trough_press_release)
 {
 	ui_t *ui = NULL;
@@ -706,8 +706,8 @@
 	ui_scrollbar_set_cb(scrollbar, &test_scrollbar_cb, &resp);
 
-	PCUT_ASSERT_FALSE(scrollbar->down_through_held);
-
-	ui_scrollbar_down_through_press(scrollbar);
-	PCUT_ASSERT_TRUE(scrollbar->down_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_held);
+
+	ui_scrollbar_lower_trough_press(scrollbar);
+	PCUT_ASSERT_TRUE(scrollbar->lower_trough_held);
 	PCUT_ASSERT_TRUE(resp.page_down);
 
@@ -717,13 +717,13 @@
 
 	ui_scrollbar_release(scrollbar, &pos);
-	PCUT_ASSERT_FALSE(scrollbar->down_through_held);
-
-	ui_scrollbar_destroy(scrollbar);
-	ui_window_destroy(window);
-	ui_destroy(ui);
-}
-
-/** Updating state of throughs when cursor or thumb moves */
-PCUT_TEST(throughs_update)
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_held);
+
+	ui_scrollbar_destroy(scrollbar);
+	ui_window_destroy(window);
+	ui_destroy(ui);
+}
+
+/** Updating state of troughs when cursor or thumb moves */
+PCUT_TEST(troughs_update)
 {
 	ui_t *ui = NULL;
@@ -754,11 +754,11 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	PCUT_ASSERT_FALSE(scrollbar->down_through_inside);
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_inside);
 
 	pos.x = 60;
 	pos.y = 22;
 
-	ui_scrollbar_throughs_update(scrollbar, &pos);
-	PCUT_ASSERT_TRUE(scrollbar->down_through_inside);
+	ui_scrollbar_troughs_update(scrollbar, &pos);
+	PCUT_ASSERT_TRUE(scrollbar->lower_trough_inside);
 
 	ui_scrollbar_destroy(scrollbar);
@@ -1082,6 +1082,6 @@
 }
 
-/** ui_scrollbar_pos_event() detects up through press/release */
-PCUT_TEST(pos_event_press_release_up_through)
+/** ui_scrollbar_pos_event() detects upper trough press/release */
+PCUT_TEST(pos_event_press_release_upper_trough)
 {
 	ui_t *ui = NULL;
@@ -1107,5 +1107,5 @@
 	PCUT_ASSERT_ERRNO_VAL(EOK, rc);
 
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
 
 	rect.p0.x = 20;
@@ -1115,21 +1115,21 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
 	/* Need to move thumb so that up through can be accessed */
 	ui_scrollbar_set_pos(scrollbar, 42);
 
 	/* Press inside up through is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 50;
 	event.vpos = 20;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_TRUE(scrollbar->up_through_held);
+	PCUT_ASSERT_TRUE(scrollbar->upper_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
 	/* Release outside (or anywhere) is claimed and relases up through */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
 	event.vpos = 32;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
@@ -1139,6 +1139,6 @@
 }
 
-/** ui_scrollbar_pos_event() detects down through press/release */
-PCUT_TEST(pos_event_press_release_down_through)
+/** ui_scrollbar_pos_event() detects lower trough press/release */
+PCUT_TEST(pos_event_press_release_lower_trough)
 {
 	ui_t *ui = NULL;
@@ -1164,5 +1164,5 @@
 	PCUT_ASSERT_ERRNO_VAL(EOK, rc);
 
-	PCUT_ASSERT_FALSE(scrollbar->up_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->upper_trough_held);
 
 	rect.p0.x = 20;
@@ -1172,18 +1172,18 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
 	/* Press inside down through is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 70;
 	event.vpos = 20;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_TRUE(scrollbar->down_through_held);
+	PCUT_ASSERT_TRUE(scrollbar->lower_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
 	/* Release outside (or anywhere) is claimed and relases up through */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
 	event.vpos = 32;
 	claim = ui_scrollbar_pos_event(scrollbar, &event);
-	PCUT_ASSERT_FALSE(scrollbar->down_through_held);
+	PCUT_ASSERT_FALSE(scrollbar->lower_trough_held);
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
@@ -1115,21 +1115,21 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	/* Need to move thumb so that up through can be accessed */
+	/* Need to move thumb so that upper trough can be accessed */
 	ui_scrollbar_set_pos(scrollbar, 42);
 
@@ -1115,21 +1115,21 @@
 	ui_scrollbar_set_pos(scrollbar, 42);
 
-	/* Press inside up through is claimed and depresses it */
+	/* Press inside upper trough is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 50;
@@ -1115,21 +1115,21 @@
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
-	/* Release outside (or anywhere) is claimed and relases up through */
+	/* Release outside (or anywhere) is claimed and relases upper trough */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
@@ -1172,18 +1172,18 @@
 	ui_scrollbar_set_rect(scrollbar, &rect);
 
-	/* Press inside down through is claimed and depresses it */
+	/* Press inside lower trough is claimed and depresses it */
 	event.type = POS_PRESS;
 	event.hpos = 70;
@@ -1172,18 +1172,18 @@
 	PCUT_ASSERT_EQUALS(ui_claimed, claim);
 
-	/* Release outside (or anywhere) is claimed and relases up through */
+	/* Release outside (or anywhere) is claimed and relases upper trough */
 	event.type = POS_RELEASE;
 	event.hpos = 41;
